==> jc-1.4.0.tar.gz: gnu/java/beans/decoder/ArrayHandler.h <==
// class gnu.java.beans.decoder.ArrayHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class 6e520b4ee0d626c9 gnu_java_beans_decoder_ArrayHandler
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractElementHandler

#include "gnu/java/beans/decoder/AbstractElementHandler.h"

#ifndef _JC_gnu_java_beans_decoder_ArrayHandler_H_
#define _JC_gnu_java_beans_decoder_ArrayHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_beans_ExceptionListener$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_org_xml_sax_Attributes$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_ArrayHandler$sub_refs	_jc_gnu_java_beans_decoder_ArrayHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_ArrayHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_ArrayHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ArrayHandler$refs	_jc_gnu_java_beans_decoder_ArrayHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_ArrayHandler$nonrefs	_jc_gnu_java_beans_decoder_ArrayHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ArrayHandler$object	_jc_gnu_java_beans_decoder_ArrayHandler$object;

typedef struct _jc_gnu_java_beans_decoder_ArrayHandler$fields_struct	_jc_gnu_java_beans_decoder_ArrayHandler$fields_struct;
typedef const struct _jc_gnu_java_beans_decoder_ArrayHandler$vmethods	_jc_gnu_java_beans_decoder_ArrayHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_ArrayHandler$vtable	_jc_gnu_java_beans_decoder_ArrayHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_ArrayHandler$vtype	_jc_gnu_java_beans_decoder_ArrayHandler$vtype;

// Class fields structure
struct _jc_gnu_java_beans_decoder_ArrayHandler$fields_struct {
	struct _jc_java_util_HashMap$object	*typeMap;
};
extern _jc_gnu_java_beans_decoder_ArrayHandler$fields_struct _jc_gnu_java_beans_decoder_ArrayHandler$class_fields;

// Constructors
extern void _jc_gnu_java_beans_decoder_ArrayHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayHandler$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_gnu_java_beans_decoder_ArrayHandler$method$startElement$c132d696183c1bce(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayHandler$object *, struct _jc_object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_ArrayHandler$method_info$startElement$c132d696183c1bce;

// Static methods
extern void _jc_gnu_java_beans_decoder_ArrayHandler$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_ArrayHandler$vmethods {
	struct _jc_object	*(*startElement$c132d696183c1bce)(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayHandler$object *, struct _jc_object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_java_beans_decoder_ArrayHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_ArrayHandler$vmethods	gnu_java_beans_decoder_ArrayHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_ArrayHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_ArrayHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ArrayHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ArrayHandler$refs {
    _jc_gnu_java_beans_decoder_ArrayHandler$sub_refs	gnu_java_beans_decoder_ArrayHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ArrayHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ArrayHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_ArrayHandler$sub_nonrefs	gnu_java_beans_decoder_ArrayHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_ArrayHandler$object {
	_jc_gnu_java_beans_decoder_ArrayHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_ArrayHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_ArrayHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_ArrayHandler$vtype _jc_gnu_java_beans_decoder_ArrayHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_ArrayHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_ArrayHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_ArrayHandler_H_ */

==> jc-1.4.6.tar.gz: gnu/java/beans/decoder/ArrayHandler.h <==
// class gnu.java.beans.decoder.ArrayHandler

// class file dependencies
// @dep_class 670cc122e6cfc20a gnu_java_beans_decoder_AbstractElementHandler
// @dep_class 6e520b4ee0d626c9 gnu_java_beans_decoder_ArrayHandler
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_beans_decoder_AbstractElementHandler

#include "gnu/java/beans/decoder/AbstractElementHandler.h"

#ifndef _JC_gnu_java_beans_decoder_ArrayHandler_H_
#define _JC_gnu_java_beans_decoder_ArrayHandler_H_

// Forward structure declarations
struct _jc_gnu_java_beans_decoder_Context$object;
struct _jc_gnu_java_beans_decoder_ElementHandler$object;
struct _jc_java_beans_ExceptionListener$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_HashMap$object;
struct _jc_org_xml_sax_Attributes$object;

// Typedefs
typedef struct _jc_gnu_java_beans_decoder_ArrayHandler$sub_refs	_jc_gnu_java_beans_decoder_ArrayHandler$sub_refs;
typedef struct _jc_gnu_java_beans_decoder_ArrayHandler$sub_nonrefs	_jc_gnu_java_beans_decoder_ArrayHandler$sub_nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ArrayHandler$refs	_jc_gnu_java_beans_decoder_ArrayHandler$refs;
typedef struct _jc_gnu_java_beans_decoder_ArrayHandler$nonrefs	_jc_gnu_java_beans_decoder_ArrayHandler$nonrefs;
typedef struct _jc_gnu_java_beans_decoder_ArrayHandler$object	_jc_gnu_java_beans_decoder_ArrayHandler$object;

typedef struct _jc_gnu_java_beans_decoder_ArrayHandler$fields_struct	_jc_gnu_java_beans_decoder_ArrayHandler$fields_struct;
typedef const struct _jc_gnu_java_beans_decoder_ArrayHandler$vmethods	_jc_gnu_java_beans_decoder_ArrayHandler$vmethods;
typedef const struct _jc_gnu_java_beans_decoder_ArrayHandler$vtable	_jc_gnu_java_beans_decoder_ArrayHandler$vtable;
typedef const struct _jc_gnu_java_beans_decoder_ArrayHandler$vtype	_jc_gnu_java_beans_decoder_ArrayHandler$vtype;

// Class fields structure
struct _jc_gnu_java_beans_decoder_ArrayHandler$fields_struct {
	struct _jc_java_util_HashMap$object	*typeMap;
};
extern _jc_gnu_java_beans_decoder_ArrayHandler$fields_struct _jc_gnu_java_beans_decoder_ArrayHandler$class_fields;

// Constructors
extern void _jc_gnu_java_beans_decoder_ArrayHandler$method$_init$7d8397207e40a3b4(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayHandler$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_gnu_java_beans_decoder_ArrayHandler$method$startElement$c132d696183c1bce(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayHandler$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_beans_decoder_ArrayHandler$method_info$startElement$c132d696183c1bce;

// Static methods
extern void _jc_gnu_java_beans_decoder_ArrayHandler$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_beans_decoder_ArrayHandler$vmethods {
	struct _jc_object	*(*startElement$c132d696183c1bce)(_jc_env *, struct _jc_gnu_java_beans_decoder_ArrayHandler$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_beans_decoder_ArrayHandler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_beans_decoder_AbstractElementHandler$vmethods	gnu_java_beans_decoder_AbstractElementHandler;
	_jc_gnu_java_beans_decoder_ArrayHandler$vmethods	gnu_java_beans_decoder_ArrayHandler;
};

// Vtype
struct _jc_gnu_java_beans_decoder_ArrayHandler$vtype {
	_jc_type			type;
	_jc_gnu_java_beans_decoder_ArrayHandler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ArrayHandler$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ArrayHandler$refs {
    _jc_gnu_java_beans_decoder_ArrayHandler$sub_refs	gnu_java_beans_decoder_ArrayHandler;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_refs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_beans_decoder_ArrayHandler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_beans_decoder_ArrayHandler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_beans_decoder_AbstractElementHandler$sub_nonrefs	gnu_java_beans_decoder_AbstractElementHandler;
    _jc_gnu_java_beans_decoder_ArrayHandler$sub_nonrefs	gnu_java_beans_decoder_ArrayHandler;
};

// Object instance structure
struct _jc_gnu_java_beans_decoder_ArrayHandler$object {
	_jc_gnu_java_beans_decoder_ArrayHandler$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_beans_decoder_ArrayHandler$vtype	*vtype;
	_jc_gnu_java_beans_decoder_ArrayHandler$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_beans_decoder_ArrayHandler$vtype _jc_gnu_java_beans_decoder_ArrayHandler$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_beans_decoder_ArrayHandler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_beans_decoder_ArrayHandler$class_object;

#endif	/* _JC_gnu_java_beans_decoder_ArrayHandler_H_ */
